@@ -1,4 +1,7 @@
-fbDeleteAdAccountUsers <-  function(user_ids = NULL, accounts_id = NULL,api_version = "v3.1",access_token = NULL){
+fbDeleteAdAccountUsers <-  function(user_ids     = NULL, 
+                                    accounts_id  = getOption("rfacebookstat.accounts_id"),
+									api_version  = getOption("rfacebookstat.api_version"),
+									access_token = getOption("rfacebookstat.access_token")){
   
   if(is.null(accounts_id)|is.null(access_token)){
     stop("Arguments accounts_id and access_token is require.")
